Package: SIMD
Type: Package
Title: Statistical Inferences with MeDIP-seq Data (SIMD) to infer the
        methylation level for each CpG site
Version: 1.31.0
Author: Yan Zhou
Maintainer: Jiadi Zhu <2160090406@email.szu.edu.cn>
Description: This package provides a inferential analysis method 
    for detecting differentially expressed CpG sites in MeDIP-seq data. It uses 
    statistical framework and EM algorithm, to identify differentially expressed 
    CpG sites. The methods on this package are described in the article 
    'Methylation-level Inferences and Detection of Differential Methylation 
    with Medip-seq Data' by Yan Zhou, Jiadi Zhu, Mingtao Zhao, Baoxue Zhang, 
    Chunfu Jiang and Xiyan Yang (2018, pending publication).
License: GPL-3
Encoding: UTF-8
LazyData: true
Depends: R (>= 3.5.0)
Imports: edgeR, statmod, methylMnM, stats, utils
Suggests: BiocStyle, knitr,rmarkdown
biocViews: ImmunoOncology, DifferentialMethylation,SingleCell,
        DifferentialExpression
VignetteBuilder: knitr
RoxygenNote: 6.0.1
git_url: https://git.bioconductor.org/packages/SIMD
git_branch: devel
git_last_commit: 3d3c8d5
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: yes
Packaged: 2026-04-29 01:08:14 UTC; biocbuild
